ratflow

A minimalistic framework for building TUI applications using a reactive architecture.
Usage
Examples of how to use the library can be found here.
Why?
I built this library around my personal preference for creating UIs with reactive systems. ratflow is designed around a reactive graph, rather than the message-driven architectures (like Elm) commonly used in many Rust UI libraries.
Contributing
If you find any errors in ratflow or just want to add a new feature feel free to submit a PR.
Credits
- The Ratatui Developers for their very simple and flexible ratatui library for cooking up terminal user interfaces.
- The Sycamore Developers for their elegant implementation of reactive primitives.