Crate ratflow

Crate ratflow 

ratflow   Action Badge Version Badge License Badge Docs Badge

A minimalistic framework for building TUI applications using a reactive architecture.

Usage

Examples of how to use the library can be found here.

Why?

I built this library around my personal preference for creating UIs with reactive systems. ratflow is designed around a reactive graph, rather than the message-driven architectures (like Elm) commonly used in many Rust UI libraries.

Contributing

If you find any errors in ratflow or just want to add a new feature feel free to submit a PR.

Credits

Structs

Runtime

Traits

Component
Render

Functions

create_interval
create_timeout
on_event
on_key
on_key_press
on_mouse
on_resize
run
run_with_terminal